// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
const Token = require('@lumino/coreutils').Token;

module.exports = {
  IMockToken: new Token('mock-token')
};
